@@ -1,8 +1,7 @@
 #![allow(dead_code)]
-use crate::backend::Backend;
 #[cfg(doc)]
 use crate::Gateway;
-use serde::{Deserialize, Serialize};
+use crate::{backend::Backend, Settings};
 use std::{any::TypeId, error::Error, fmt::Debug, sync::Arc};
 use thiserror::Error;
 
@@ -22,12 +21,24 @@ pub enum DatabaseError<E: Error = !> {
 /// A database for easily interacting with a [`Backend`].
 #[derive(Debug)]
 pub struct Database<B: Backend> {
-    table_name: String,
-    backend: Arc<B>,
+    pub(crate) name: String,
+    pub(crate) backend: Arc<B>,
     type_id: TypeId,
 }
 
 impl<B: Backend> Database<B> {
+    /// Gives access to the raw [`Backend`] instance.
+    ///
+    /// # Safety
+    ///
+    /// Accessing the backend functions directly isn't inheritly unsafe, however
+    /// care must be taken to ensure the data isn't modified directly, and
+    /// that [`Backend::shutdown`] isn't directly called.
+    #[must_use]
+    pub unsafe fn backend(&self) -> &B {
+        &*self.backend
+    }
+
     pub(crate) async fn new(
         table_name: String,
         backend: Arc<B>,
@@ -36,7 +47,7 @@ impl<B: Backend> Database<B> {
         backend.ensure_table(&table_name).await?;
 
         Ok(Self {
-            table_name,
+            name: table_name,
             backend,
             type_id,
         })
@@ -44,7 +55,7 @@ impl<B: Backend> Database<B> {
 
     pub(crate) fn check<S>(&self) -> Result<(), DatabaseError<B::Error>>
     where
-        S: Debug + Serialize + for<'de> Deserialize<'de> + 'static,
+        S: Settings + 'static,
     {
         let type_of_val = TypeId::of::<S>();
 
@@ -60,7 +71,7 @@ impl<B: Backend> Clone for Database<B> {
     fn clone(&self) -> Self {
         Self {
             backend: self.backend.clone(),
-            table_name: self.table_name.clone(),
+            name: self.name.clone(),
             type_id: self.type_id,
         }
     }
