@@ -1,9 +1,8 @@
 //! The base structure to use for starchart.
 
-use crate::{backend::Backend, database::DatabaseError, Database};
+use crate::{backend::Backend, database::DatabaseError, Database, Settings};
 use dashmap::{mapref::one::Ref, DashMap};
 use futures::executor::block_on;
-use serde::{Deserialize, Serialize};
 use std::{
     any::TypeId,
     fmt::{Debug, Formatter, Result as FmtResult},
@@ -30,7 +29,7 @@ where
 
     /// Returns the key of the [`Database`].
     #[must_use]
-    pub fn key(&'a self) -> &'a String {
+    pub fn key(&'a self) -> &'a str {
         self.inner.key()
     }
 
@@ -74,6 +73,18 @@ pub struct Gateway<B: Backend> {
 }
 
 impl<B: Backend> Gateway<B> {
+    /// Gives access to the raw [`Backend`] instance.
+    ///
+    /// # Safety
+    ///
+    /// Accessing the backend functions directly isn't inheritly unsafe, however
+    /// care must be taken to ensure the data isn't modified directly, and
+    /// that [`Backend::shutdown`] isn't directly called.
+    #[must_use]
+    pub unsafe fn backend(&self) -> &B {
+        &*self.backend
+    }
+
     /// Creates a new [`Gateway`], and initializes the [`Backend`].
     ///
     /// # Errors
@@ -94,12 +105,12 @@ impl<B: Backend> Gateway<B> {
     ///
     /// An error will be raised if the type provided is not the same as the type provided
     /// when the database was created.
-    pub async fn acquire<'a, S>(
-        &'a self,
+    pub async fn acquire<S>(
+        &self,
         table_name: String,
-    ) -> Result<DbRef<'a, B>, DatabaseError<B::Error>>
+    ) -> Result<DbRef<'_, B>, DatabaseError<B::Error>>
     where
-        S: Debug + Serialize + for<'de> Deserialize<'de> + 'static,
+        S: Settings + 'static,
     {
         let exists = self.get::<S>(&table_name)?;
 
@@ -112,12 +123,12 @@ impl<B: Backend> Gateway<B> {
 
     #[allow(clippy::missing_errors_doc)]
     /// Creates a new [`Database`].
-    pub async fn create<'a, S>(
-        &'a self,
+    pub async fn create<S>(
+        &self,
         table_name: String,
-    ) -> Result<DbRef<'a, B>, DatabaseError<B::Error>>
+    ) -> Result<DbRef<'_, B>, DatabaseError<B::Error>>
     where
-        S: Debug + Serialize + for<'de> Deserialize<'de> + 'static,
+        S: Settings + 'static,
     {
         let type_id = TypeId::of::<S>();
 
@@ -139,7 +150,7 @@ impl<B: Backend> Gateway<B> {
         table_name: &str,
     ) -> Result<Option<DbRef<'a, B>>, DatabaseError<B::Error>>
     where
-        S: Debug + Serialize + for<'de> Deserialize<'de> + 'static,
+        S: Settings + 'static,
     {
         let map_ref = unsafe {
             let temp = self.databases.get(table_name);
@@ -156,17 +167,57 @@ impl<B: Backend> Gateway<B> {
         Ok(Some(DbRef::new(map_ref)))
     }
 
+    /// Deletes a [`Database`], uses [`Backend::delete_table`] under the hood.
+    ///
+    /// # Errors
+    ///
+    /// Can return errors from [`Gateway::get`], as well as from [`Backend::delete_table`].
+    ///
+    /// [`Gateway::get`]: Self::get
+    pub async fn delete<S>(&self, table_name: &str) -> Result<(), DatabaseError<B::Error>>
+    where
+        S: Settings + 'static,
+    {
+        let table = match self.get::<S>(table_name)? {
+            Some(db) => db,
+            None => return Ok(()),
+        };
+
+        self.backend.delete_table(&table.name).await?;
+
+        self.databases.remove(&table.name);
+
+        Ok(())
+    }
+
+    /// Deletes a [`Database`] from the [`Gateway`] without checking if it
+    /// exists first.
+    ///
+    /// # Safety
+    ///
+    /// This uses both [`Result::unwrap_unchecked`] and [`Option::unwrap_unchecked`] under the hood.
+    pub async unsafe fn delete_unchecked<S>(&self, table_name: &str)
+    where
+        S: Settings + 'static,
+    {
+        let table = self.get_unchecked::<S>(table_name);
+
+        self.backend
+            .delete_table(&table.name)
+            .await
+            .unwrap_unchecked();
+
+        self.databases.remove(&table.name);
+    }
+
     /// Gets a [`Database`] from the cache without verifying that it exists.
     ///
     /// # Safety
     ///
     /// This uses both [`Result::unwrap_unchecked`] and [`Option::unwrap_unchecked`] under the hood.
-    ///
-    /// [`Result::unwrapped_unchecked`]: std::result::Result::unwrap_unchecked
-    /// [`Option::unwrap_unchecked`]: std::option::Option::unwrap_unchecked
     pub unsafe fn get_unchecked<'a, S>(&'a self, table_name: &str) -> DbRef<'a, B>
     where
-        S: Debug + Serialize + for<'de> Deserialize<'de> + 'static,
+        S: Settings + 'static,
     {
         let map_ref = self.databases.get(table_name).unwrap_unchecked();
 
